@@ -1,9 +1,9 @@
 `plot.stockReturns` <-
 function(x, lty=NULL, col=NULL,
-lwd=NULL, ylim=NULL, xlab='time', ylab='Value', legend=TRUE, type='l', ...){
+lwd=NULL, ylim=NULL, xlab='Time', ylab='Value', legend=TRUE, type='l', ...){
 	n <- dim(x$R)
 	if(is.null(ylim)[1]){
-		ylim <- range(apply(1+x$R[n[1]:1,], 2, cumprod))
+		ylim <- range(apply(1+x$R[n[1]:1,,drop=FALSE], 2, cumprod))
 	}
 	if(is.null(lty)){
 		lty <- 1:n[2]
@@ -20,11 +20,12 @@ lwd=NULL, ylim=NULL, xlab='time', ylab='Value', legend=TRUE, type='l', ...){
 	} else if(length(col) < n[2]){
 		col <- rep(col, n[2])
 	}
-	plot(cumprod(1+rev(x$R[,1])), ylim=ylim, ylab=ylab, col=col[1],
+	X <- rev(as.Date(row.names(x$R)))
+	plot(X, cumprod(1+rev(x$R[,1])), ylim=ylim, ylab=ylab, col=col[1],
 		lty=lty[1], lwd=lwd[1], xlab=xlab, type=type, ...)
 	if(n[2] > 1 & type != 'n'){
 		for(i in 2:n[2]){
-			lines(cumprod(1+rev(x$R[,i])), col=col[i], lty=lty[i], lwd=lwd[i], type=type)
+			lines(X, cumprod(1+rev(x$R[,i])), col=col[i], lty=lty[i], lwd=lwd[i], type=type)
 		}
 	}
 	if(legend){
