@@ -2,7 +2,7 @@
 function(model, riskRange=2, detail=100, effFrontier=FALSE, add=FALSE, type='l', xlab='Risk', ylab='Expected Return', doNotPlot=FALSE, ...){
 	#===> must have short-selling <===#
 	if(!model$shorts){
-		stop("Short selling must be permitted for portCloud.\n")
+		stop("Short selling must be permitted.\n")
 	}
 	
 	#===> prevent multiple warnings in optimalPort <===#
@@ -10,10 +10,6 @@ function(model, riskRange=2, detail=100, effFrontier=FALSE, add=FALSE, type='l',
 		model$shorts <- TRUE
 		warning('Short sales are always allowed when no model is provided.\n')
 	}
-	if(!model$shorts & model$model %in% 'MGM'){
-		model$shorts <- TRUE
-		warning('Short sales are always allowed with the multigroup model.\n')
-	}
 	
 	#===> get two points on PP curve, their returns & cov <===#
 	G1  <- optimalPort(model, Rf=-1000)
